Inversion

Struct Inversion 

pub struct Inversion { /* private fields */ }
A planar geometric inversion represented by center and radius.

Implementations

Source

impl Inversion

pub fn try_new(center: Point2, radius: f64) -> Result<Self, GeometryError>

Creates an inversion with a finite center and positive finite radius.

Errors

Returns a GeometryError when the center is non-finite or the radius is invalid.

pub const fn center(self) -> Point2

Returns the inversion center.

pub const fn radius(self) -> f64

Returns the inversion radius.

pub const fn radius_squared(self) -> f64

Returns the squared inversion radius.