pub struct Inversion { /* private fields */ }Expand description
A planar geometric inversion represented by center and radius.
Implementations
Sourceimpl Inversion
impl Inversion
Sourcepub fn try_new(center: Point2, radius: f64) -> Result<Self, GeometryError>
pub fn try_new(center: Point2, radius: f64) -> Result<Self, GeometryError>
Creates an inversion with a finite center and positive finite radius.
Errors
Returns a GeometryError when the center is non-finite or the radius is invalid.
Sourcepub const fn radius_squared(self) -> f64
pub const fn radius_squared(self) -> f64
Returns the squared inversion radius.